@@ -1,10 +1,16 @@
 """Utility functions for SSL/TSL certificate handling."""
 
-from urllib.parse import urlsplit
 from ssl import get_server_certificate
+from typing import (
+    Callable,
+    Tuple,
+)
+from urllib.parse import urlsplit
 
 
-def get_host_certificate(uri, get_func=get_server_certificate):
+def get_host_certificate(
+    uri: str, get_func: Callable[[Tuple[str, int]], str] = get_server_certificate
+) -> str:
     """Return a string with the host certificate.
 
     :param str uri: the host URI, in the form :data:`[scheme://]host[:port]`.
@@ -16,13 +22,13 @@ def get_host_certificate(uri, get_func=get_server_certificate):
         # This is a complete URL, just take the host
         uri = split.netloc
     else:
-        uri, _ = uri.split('/', 1)
+        uri, _ = uri.split("/", 1)
 
-    if ':' in uri:
-        host, port = uri.split(':', maxsplit=1)
-        port = int(port)
+    if ":" in uri:
+        host, port = uri.split(":", maxsplit=1)
+        int_port = int(port)
     else:
         host = uri
-        port = 443
-    cert = get_func((host, port))
+        int_port = 443
+    cert = get_func((host, int_port))
     return cert.strip()
